<?php

namespace Drupal\navigation_local_tasks\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure navigation local tasks form.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'navigation_local_tasks_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['navigation_local_tasks.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $disallowed_tasks = $this->config('navigation_local_tasks.settings')->get('disallowed_tasks');
    if (!is_array($disallowed_tasks)) {
      $disallowed_tasks = [];
    }
    $default = implode("\r\n", $disallowed_tasks);
    $form['disallowed_tasks'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Disallowed tasks'),
      '#default_value' => $default,
      '#description' => $this->t('Enter route names of tasks to exclude. One task per line. For example, enter <code>entity.node.version_history</code> to exclude the <em>Versions</em> local task.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // TODO: Split into array, one value per row.
    $disallowed_tasks = $form_state->getValue('disallowed_tasks');
    $value = explode("\r\n", $disallowed_tasks);
    $value = array_filter($value);
    $this->configFactory()->getEditable('navigation_local_tasks.settings')
      ->set('disallowed_tasks', $value)
      ->save();
  }

}
