<?php

declare(strict_types=1);

namespace Drupal\navigation_local_tasks\Plugin\Block;

use Drupal\Core\Block\Attribute\Block;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\navigation_local_tasks\NavigationLocalTasksBase;

/**
 * Provides a 'local tasks button' block.
 */
#[Block(
  id: "navigation_local_tasks_button",
  admin_label: new TranslatableMarkup("Local tasks button")
)]
final class NavigationLocalTasksButton extends NavigationLocalTasksBase {

  /**
   * {@inheritdoc}
   *
   * @see \Drupal\Core\Menu\Plugin\Block\LocalTasksBlock
   */
  public function build(): array {
    $build = $this->getLocalTasks();

    if ($this->adminContext->isAdminRoute() || empty($build['#local_tasks'])) {
      return [];
    }

    // Assemble the build array.
    $button = [
      '#type' => 'dropbutton',
      '#links' => [],
    ];

    foreach ($build['#local_tasks'] as $key => $task) {
      $button['#links'][] = [
        'title' => $task['#link']['title'],
        'url' => $task['#link']['url'],
      ];
    }

    return $build + $button;
  }

}
