<?php

declare(strict_types=1);

namespace Drupal\navigation_local_tasks\Plugin\Block;

use Drupal\Component\Utility\Html;
use Drupal\Core\Block\Attribute\Block;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\navigation_local_tasks\NavigationLocalTasksBase;

/**
 * Provides a 'local tasks details' block.
 */
#[Block(
  id: "navigation_local_tasks_details",
  admin_label: new TranslatableMarkup("Local tasks details")
)]
final class NavigationLocalTasksDetails extends NavigationLocalTasksBase {

  /**
   * {@inheritdoc}
   *
   * @see \Drupal\Core\Menu\Plugin\Block\LocalTasksBlock
   */
  public function build(): array {
    $build = $this->getLocalTasks();

    if (is_null($this->routeMatch->getParameter('node')) || empty($build['#local_tasks'])) {
      return [];
    }

    // Assemble the build array.
    $details = [
      '#theme' => 'navigation_local_tasks_details',
      '#title' => $this->configuration['label'],
      '#links' => [],
      '#attached' => [
        'library' => ['navigation_local_tasks/details'],
      ],
    ];

    foreach ($build['#local_tasks'] as $key => $task) {
      $details['#links'][] = (object) [
        'title' => $task['#link']['title'],
        'url' => $task['#link']['url'],
        'class' => 'toolbar-button--icon--' . Html::cleanCssIdentifier(str_replace('.', '-', $key)),
      ];
    }

    return $build + $details;
  }

}
