<?php

declare(strict_types=1);

namespace Drupal\navigation_local_tasks\Plugin\Block;

use Drupal\Component\Utility\Html;
use Drupal\Core\Block\Attribute\Block;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Url;
use Drupal\navigation_local_tasks\NavigationLocalTasksBase;

/**
 * Provides a 'local tasks menu' block.
 */
#[Block(
  id: "navigation_local_tasks_menu",
  admin_label: new TranslatableMarkup("Local tasks menu")
)]
final class NavigationLocalTasksMenu extends NavigationLocalTasksBase {

  /**
   * {@inheritdoc}
   *
   * @see \Drupal\Core\Menu\Plugin\Block\LocalTasksBlock
   */
  public function build(): array {
    $build = $this->getLocalTasks();

    if ($this->adminContext->isAdminRoute() || empty($build['#local_tasks'])) {
      return [];
    }

    // Assemble the build array.
    $navigation = [
      '#theme' => 'navigation_menu',
      '#title' => $this->configuration['label'],
      '#attributes' => [],
      '#items' => [],
      '#attached' => [
        'library' => ['navigation_local_tasks/menu'],
      ],
    ];

    $items = [];
    foreach ($build['#local_tasks'] as $key => $task) {
      $items[] = (object) [
        'title' => $task['#link']['title'],
        'url' => $task['#link']['url'],
        'original_link' => (object) [
          'pluginId' => $key,
        ],
        'class' => Html::cleanCssIdentifier(str_replace('.', '-', $key)),
      ];
    }

    $item = (object) [
      'title' => $this->configuration['label'],
      'url' => Url::fromRoute('<button>'),
      'original_link' => (object) [
        'pluginId' => $this->getPluginId(),
      ],
      'class' => Html::cleanCssIdentifier(str_replace('.', '-', $this->getPluginId())),
      'below' => $items,
    ];

    $navigation['#items'][] = $item;

    return $build + $navigation;
  }

}
